tonalitytools.ChordClass
========================

.. inheritance-diagram:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.bass

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.cardinality

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.extent

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.figured_bass

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.inversion

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.inversion_equivalent_diatonic_interval_class_vector

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSet <abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet>`

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.markup

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.named_chromatic_pitch_classes

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSet <abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet>`

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.numbered_chromatic_pitch_class_set

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSet <abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet>`

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.quality_indicator

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.quality_pair

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.root

.. autoattribute:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.root_string

Methods
-------

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.copy

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.difference

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.intersection

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.isdisjoint

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.issubset

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.issuperset

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.order_by

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSet <abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet>`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.symmetric_difference

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.transpose

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.union

   .. note:: Inherited from `__builtin__.frozenset`

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__and__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__cmp__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__contains__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__eq__

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__ge__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__gt__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__hash__

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSet <abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet>`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__iter__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__le__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__len__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__lt__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__ne__

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__or__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__rand__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__repr__

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__ror__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__rsub__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__rxor__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__str__

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSet <abjad.tools.pitchtools.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet.NamedChromaticPitchClassSet>`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__sub__

   .. note:: Inherited from `__builtin__.frozenset`

.. automethod:: abjad.tools.tonalitytools.ChordClass.ChordClass.ChordClass.__xor__

   .. note:: Inherited from `__builtin__.frozenset`
